@@ -50,7 +50,7 @@ def blobs(
         cluster_std=cluster_std,
         random_state=0,
     )
-    return AnnData(X, obs=dict(blobs=y.astype(str)))
+    return AnnData(X, obs=dict(blobs=y.astype(str)), dtype=X.dtype)
 
 
 @check_datasetdir_exists
@@ -119,11 +119,11 @@ def moignard15() -> AnnData:
     Annotated data matrix.
     """
     filename = settings.datasetdir / 'moignard15/nbt.3154-S3.xlsx'
-    backup_url = 'http://www.nature.com/nbt/journal/v33/n3/extref/nbt.3154-S3.xlsx'
+    backup_url = 'https://static-content.springer.com/esm/art%3A10.1038%2Fnbt.3154/MediaObjects/41587_2015_BFnbt3154_MOESM4_ESM.xlsx'
     adata = read(filename, sheet='dCt_values.txt', backup_url=backup_url)
     # filter out 4 genes as in Haghverdi et al. (2016)
     gene_subset = ~np.in1d(adata.var_names, ['Eif2b1', 'Mrpl19', 'Polr2a', 'Ubc'])
-    adata = adata[:, gene_subset]  # retain non-removed genes
+    adata = adata[:, gene_subset].copy()  # retain non-removed genes
     # choose root cell for DPT analysis as in Haghverdi et al. (2016)
     adata.uns["iroot"] = 532  # note that in Matlab/R, counting starts at 1
     # annotate with Moignard et al. (2015) experimental cell groups
@@ -179,7 +179,7 @@ def paul15() -> AnnData:
         clusters = f['cluster.id'][()].flatten().astype(int)
         infogenes_names = f['info.genes_strings'][()].astype(str)
     # each row has to correspond to a observation, therefore transpose
-    adata = AnnData(X.transpose())
+    adata = AnnData(X.transpose(), dtype=X.dtype)
     adata.var_names = gene_names
     adata.row_names = cell_names
     # names reflecting the cell type identifications from the paper
@@ -302,11 +302,16 @@ def pbmc3k_processed() -> AnnData:
         warnings.filterwarnings("ignore", category=FutureWarning, module="anndata")
         return read(
             settings.datasetdir / 'pbmc3k_processed.h5ad',
-            backup_url='https://raw.githubusercontent.com/chanzuckerberg/cellxgene/master/example-dataset/pbmc3k.h5ad',
+            backup_url='https://raw.githubusercontent.com/chanzuckerberg/cellxgene/main/example-dataset/pbmc3k.h5ad',
         )
 
 
-def _download_visium_dataset(sample_id: str, base_dir: Optional[Path] = None):
+def _download_visium_dataset(
+    sample_id: str,
+    spaceranger_version: str,
+    base_dir: Optional[Path] = None,
+    download_image: bool = False,
+):
     """
     Params
     ------
@@ -314,13 +319,15 @@ def _download_visium_dataset(sample_id: str, base_dir: Optional[Path] = None):
         String name of example visium dataset.
     base_dir
         Where to download the dataset to.
+    download_image
+        Whether to download the high-resolution tissue section.
     """
     import tarfile
 
     if base_dir is None:
         base_dir = settings.datasetdir
 
-    url_prefix = f'http://cf.10xgenomics.com/samples/spatial-exp/1.0.0/{sample_id}/'
+    url_prefix = f'https://cf.10xgenomics.com/samples/spatial-exp/{spaceranger_version}/{sample_id}/'
 
     sample_dir = base_dir / sample_id
     sample_dir.mkdir(exist_ok=True)
@@ -342,6 +349,13 @@ def _download_visium_dataset(sample_id: str, base_dir: Optional[Path] = None):
         backup_url=url_prefix + f"{sample_id}_filtered_feature_bc_matrix.h5",
     )
 
+    # Download image
+    if download_image:
+        _utils.check_presence_download(
+            filename=sample_dir / "image.tif",
+            backup_url=url_prefix + f"{sample_id}_image.tif",
+        )
+
 
 @check_datasetdir_exists
 def visium_sge(
@@ -356,7 +370,27 @@ def visium_sge(
         'V1_Mouse_Brain_Sagittal_Posterior_Section_2',
         'V1_Mouse_Brain_Sagittal_Anterior',
         'V1_Mouse_Brain_Sagittal_Anterior_Section_2',
+        'V1_Human_Brain_Section_1',
+        'V1_Human_Brain_Section_2',
+        'V1_Adult_Mouse_Brain_Coronal_Section_1',
+        'V1_Adult_Mouse_Brain_Coronal_Section_2',
+        # spaceranger version 1.2.0
+        'Targeted_Visium_Human_Cerebellum_Neuroscience',
+        'Parent_Visium_Human_Cerebellum',
+        'Targeted_Visium_Human_SpinalCord_Neuroscience',
+        'Parent_Visium_Human_SpinalCord',
+        'Targeted_Visium_Human_Glioblastoma_Pan_Cancer',
+        'Parent_Visium_Human_Glioblastoma',
+        'Targeted_Visium_Human_BreastCancer_Immunology',
+        'Parent_Visium_Human_BreastCancer',
+        'Targeted_Visium_Human_OvarianCancer_Pan_Cancer',
+        'Targeted_Visium_Human_OvarianCancer_Immunology',
+        'Parent_Visium_Human_OvarianCancer',
+        'Targeted_Visium_Human_ColorectalCancer_GeneSignature',
+        'Parent_Visium_Human_ColorectalCancer',
     ] = 'V1_Breast_Cancer_Block_A_Section_1',
+    *,
+    include_hires_tiff: bool = False,
 ) -> AnnData:
     """\
     Processed Visium Spatial Gene Expression data from 10x Genomics.
@@ -366,10 +400,25 @@ def visium_sge(
     ----------
     sample_id
         The ID of the data sample in 10x’s spatial database.
+    include_hires_tiff
+        Download and include the high-resolution tissue image (tiff) in `adata.uns["spatial"][sample_id]["metadata"]["source_image_path"]`.
 
     Returns
     -------
     Annotated data matrix.
     """
-    _download_visium_dataset(sample_id)
-    return read_visium(settings.datasetdir / sample_id)
+    if "V1_" in sample_id:
+        spaceranger_version = "1.1.0"
+    else:
+        spaceranger_version = "1.2.0"
+    _download_visium_dataset(
+        sample_id, spaceranger_version, download_image=include_hires_tiff
+    )
+    if include_hires_tiff:
+        adata = read_visium(
+            settings.datasetdir / sample_id,
+            source_image_path=settings.datasetdir / sample_id / "image.tif",
+        )
+    else:
+        adata = read_visium(settings.datasetdir / sample_id)
+    return adata
